IF OBJECT_ID('[NuGetPackages_Latest]') IS NOT NULL DROP VIEW [NuGetPackages_Latest]
GO

CREATE VIEW [NuGetPackages_Latest]
AS
	SELECT P.[Feed_Id],
	       P.[Package_Id],
		   P.[Version_Text],
		   P.[TargetFrameworks_Text],
		   P.[Published_Date],
		   P.[Package_Size],
		   P.[NuspecFile_Bytes],
		   P.[PackageHash_Bytes],
		   P.[PackageHash_SHA1_Bytes],
		   P.[Symbols_Indicator],
		   P.[Source_Indicator],
		   P.[Cached_Indicator],
		   P.[Prerelease_Indicator],
		   P.[LastDownloaded_Date],
		   [Version_Download_Count] = P.[Download_Count],
		   [Total_Download_Count] = (SELECT SUM(P2.[Download_Count])
		                               FROM [NuGetPackages] P2
									  WHERE P2.[Feed_Id] = P.[Feed_Id]
									    AND P2.[Package_Id] = P.[Package_Id])
	  FROM (SELECT [Feed_Id],
	               [Package_Id],
				   [Version_Text],
				   [TargetFrameworks_Text],
				   [Published_Date],
				   [Package_Size],
				   [Download_Count],
				   [NuspecFile_Bytes],
				   [PackageHash_Bytes],
				   [PackageHash_SHA1_Bytes],
				   [Symbols_Indicator],
				   [Source_Indicator],
				   [Cached_Indicator],
				   [Prerelease_Indicator],
				   [LastDownloaded_Date],
	               [Rank] = ROW_NUMBER() OVER(PARTITION BY [Feed_Id], [Package_Id]
		                                          ORDER BY [Major_Number] DESC, [Minor_Number] DESC, [Patch_Number] DESC, [Build_Number] DESC, [Prerelease_Indicator], [Prerelease_Text] DESC)
	          FROM [NuGetPackages]
			 WHERE [Listed_Indicator] = 'Y') P
	 WHERE P.[Rank] = 1