EXEC [__AddStoredProcInfo]
    /* StoredProc_Name         */ 'DockerImages_CreateImage',
    /* Internal_Indicator      */ 'Y',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ NULL,
    /* Description_Text        */ 'Creates an image.'
GO

IF OBJECT_ID('[DockerImages_CreateImage]') IS NOT NULL DROP PROCEDURE [DockerImages_CreateImage]
GO

SET QUOTED_IDENTIFIER ON
GO
SET ANSI_NULLS ON
GO

CREATE PROCEDURE [DockerImages_CreateImage]
(
	@Feed_Id INT,
	@Repository_Name VARCHAR(255),
	@Tag_Name VARCHAR(128),
	@Image_Digest VARCHAR(128),
	@ManifestJson_Bytes VARBINARY(MAX),
	@Cached_Indicator YNINDICATOR = NULL
)
AS
BEGIN

SET NOCOUNT ON

BEGIN TRY
	BEGIN TRANSACTION

	IF NOT EXISTS(SELECT * FROM [DockerImages] WHERE [Feed_Id] = @Feed_Id AND [Repository_Name] = @Repository_Name AND [Image_Digest] = @Image_Digest)
	BEGIN

		INSERT INTO [DockerImages]
		(
			[Feed_Id],
			[Repository_Name],
			[Image_Digest],
			[ManifestJson_Bytes],
			[Download_Count],
			[Published_Date],
			[Cached_Indicator]
		)
		VALUES
		(
			@Feed_Id,
			@Repository_Name,
			@Image_Digest,
			@ManifestJson_Bytes,
			0,
			GETUTCDATE(),
			COALESCE(@Cached_Indicator, 'N')
		)

	END

	IF @Tag_Name IS NOT NULL
	BEGIN

		IF EXISTS(SELECT * FROM [DockerImageTags] WHERE [Feed_Id] = @Feed_Id AND [Repository_Name] = @Repository_Name AND [Tag_Name] = @Tag_Name)
		BEGIN
			UPDATE [DockerImageTags]
			   SET [Image_Digest] = @Image_Digest
			 WHERE [Feed_Id] = @Feed_Id
			   AND [Repository_Name] = @Repository_Name
			   AND [Tag_Name] = @Tag_Name
		END
		ELSE
		BEGIN
			INSERT INTO [DockerImageTags]
			(
				[Feed_Id],
				[Repository_Name],
				[Tag_Name],
				[Image_Digest]
			)
			VALUES
			(
				@Feed_Id,
				@Repository_Name,
				@Tag_Name,
				@Image_Digest
			)
		END

	END

	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH

END
GO

GRANT EXECUTE ON [DockerImages_CreateImage] TO [ProGetUser_Role]
GO